# -*- coding: utf-8 -*-
# @Time    : 2020-06-16 11:36
# @Author  : xzr
# @File    : __init__
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc    : 

from django.utils.translation import gettext_lazy as _
#from .query import Query
#from .statistic import Statistic


